twqq
####
一个基于tornado的异步的WebQQ客户端库


Features
########
* 易于使用
* 易于扩展
* 可长时间维持在线状态
* 基于Tornado的高效异步库


TODO
####
* 完善协议
* ``修复临时消息(已修复)``

Changelog
#########
Version 0.2.4 (2014-04-21)
--------------------------
* 添加登出请求
* 添加手动刷新好友信息
* 添加手动刷新群信息

Version 0.2.3 (2014-04-21)
--------------------------
* 增加好友状态管理
* 添加一些接口
* 增加获取QQ号码的接口
* 处理带图片的消息
* 修复一些讨论组bug

Version 0.2.2 (2014-04-18)
--------------------------

* 抽象WebQQ的数据结构(好友/群/讨论组)
* 完善讨论组协议
* 一些接口的改变
* 添加文件接收

Version 0.1.7 (2014-03-05)
-------------------------
* 增加讨论组支持

已知Bug
#######

* 有时发送一条消息时, 服务器会发送两条



.. 如果您觉得功能不错, 您可以 |imglink|_ 让我更多的支持开源事业

.. .. |imglink| image:: https://img.alipay.com/sys/personalprod/style/mc/btn-index.png

.. .. _imglink: http://me.alipay.com/woodd
